function varargout = DFP_GUI(varargin)

%DFP_GUI
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $

gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
    'gui_Singleton',  gui_Singleton, ...
    'gui_OpeningFcn', @DFP_GUI_OpeningFcn, ...
    'gui_OutputFcn',  @DFP_GUI_OutputFcn, ...
    'gui_LayoutFcn',  [] , ...
    'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end

addpath('./SupportFiles/')

% End initialization code - DO NOT EDIT

end

% --- Executes just before DFP_GUI is made visible.
function DFP_GUI_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to DFP_GUI (see VARARGIN)

% Choose default command line output for DFP_GUI
handles.output = hObject;

% User stuff:
home
addpath('../')


% Create initial settings
handles = setData(handles);
guidata(hObject,handles);

handles = guidata(hObject);

handles.stopped = true;
handles.guiTimer = timer;
hObjectFigure = hObject;
set(handles.guiTimer,'Period',handles.plotSettings.matlabTimerStep,'ExecutionMOde','FixedRate','StartDelay',0.1,'TimerFcn',@(hObject, eventdata) updateGUI(hObject, eventdata, hObjectFigure));

handles.plotHandles = DFP_setPlotHandles(handles);

% Update handles structure
guidata(hObject, handles);
updateData(0,hObject);
setAxis(handles.modelState.rAnkle,hObject)
drawData(hObject);

end

% --- Outputs from this function are returned to the command line.
function varargout = DFP_GUI_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
end


% --- Executes on button press in startButton.
function startButton_Callback(hObject, eventdata, handles)
% hObject    handle to startButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%     updateData(handles.plotSettings.matlabTimerStep, hObject);
%     drawData(hObject);
%
handles.stopped = ~handles.stopped;
if handles.stopped
    set(hObject, 'String', 'Start');
    stop(handles.guiTimer);
else
    set(hObject, 'String', 'Stop');
    start(handles.guiTimer);
end
guidata(hObject,handles);
end

% --- Executes on button press in resetButton.
function resetButton_Callback(hObject, eventdata, handles)
% hObject    handle to resetButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
clc
handles = setData(handles);
allHandles = guihandles(hObject);
handles.plotData.ConstantStepping = get(allHandles.Constant,'Value');
handles.plotData.DFPControl = get(allHandles.DFC,'Value');
guidata(hObject, handles);
setAxis(handles.modelState.rAnkle,hObject)
updateData(0,hObject);
drawData(hObject);

end


% --- Executes when user attempts to close figure1.
function figure1_CloseRequestFcn(hObject, eventdata, handles)
% hObject    handle to figure1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

stop(handles.guiTimer);
delete(handles.guiTimer);
delete(timerfindall); % extra check
delete(hObject);
end

function updateGUI(hObjectTimer, eventdata, hObject)
handles = guidata(hObject);
updateData(handles.plotSettings.stateTimeStep, hObject);
drawData(hObject);
drawnow
end

% --- Executes on mouse press over figure background, over a disabled or
% --- inactive control, or over an axes background.
function figure1_WindowButtonDownFcn(hObject, eventdata, handles)
handles = guidata(hObject);
altClick = strcmp(get(hObject, 'SelectionType'), 'alt');
normalClick = strcmp(get(hObject, 'SelectionType'), 'normal');
doubleClick = strcmp(get(hObject, 'SelectionType'), 'open');

currentPointCartesianSpace = get(handles.CartesianSpace, 'CurrentPoint');
currentPointCartesianSpace = currentPointCartesianSpace(2, 1 : 2)';

currentPointStateSpaceX = get(handles.StateSpaceX, 'CurrentPoint');
currentPointStateSpaceX = currentPointStateSpaceX(2, 1 : 2)';

currentPointStateSpaceY = get(handles.StateSpaceY, 'CurrentPoint');
currentPointStateSpaceY = currentPointStateSpaceY(2, 1 : 2)';

inCartesianSpace = currentPointInAxes(currentPointCartesianSpace,get(handles.CartesianSpace, 'XLim'),get(handles.CartesianSpace, 'YLim'));
inStateSpaceX = currentPointInAxes(currentPointStateSpaceX,get(handles.StateSpaceX, 'XLim'),get(handles.StateSpaceX, 'YLim'));
inStateSpaceY = currentPointInAxes(currentPointStateSpaceY,get(handles.StateSpaceY, 'XLim'),get(handles.StateSpaceY, 'YLim'));

if inCartesianSpace
    if normalClick || doubleClick
        %% Slight attractor to rIC, to make user easy
        if norm(handles.plotData.rCPAtMinStep  - currentPointCartesianSpace) < 0.05
            currentPointCartesianSpace = handles.plotData.rCPAtMinStep ;
        end
        stepTo(currentPointCartesianSpace,hObject);
    elseif altClick
        handles.modelState.rd = handles.modelState.rd - 0.25*(currentPointCartesianSpace-handles.modelState.r)/norm(currentPointCartesianSpace-handles.modelState.r);
        handles.modelState.rIC = handles.modelState.r + handles.modelState.rd;
        handles.modelState.r2 = handles.modelState.r - handles.modelState.rd;
        guidata(hObject,handles);
    end
elseif inStateSpaceX
    % a relative step is not implemented 
elseif inStateSpaceY
    % a relative step is not implemented 
end
     function bool = currentPointInAxes(currentPoint,xLim,yLim)
        bool  = currentPoint(1) >= xLim(1) && ...
            currentPoint(1) <= xLim(2) && ...
            currentPoint(2) >= yLim(1) && ...
            currentPoint(2) <= yLim(2);
    end
end

% --- Executes on button press in Constant.
function Constant_Callback(hObject, eventdata, handles)
handles.plotData.ConstantStepping = get(hObject,'Value');
guidata(hObject,handles);
if handles.plotData.ConstantStepping
    handles = guidata(hObject);
    set(handles.DFC,'Value',false);
    handles.plotData.DFPControl = false;
end
guidata(hObject,handles);
end


%% FUNCTION: UPDATE DATA
function updateData(timeStep, hObject)

handles = guidata(hObject);

% - DECISION MAKING: SHOULD WE STEP? -
% Update current modelState: step if there is an plotData.rAnkleNext and we're allowed to step
if (handles.modelState.dTWait == 0)
    if  ~isempty(handles.plotData.rAnkleNext) % Mouse/manual input
        stepTo(handles.plotData.rAnkleNext, hObject);
    elseif handles.plotData.ConstantStepping == true || handles.plotData.DFPControl == true % Autostep input
        CheckDoAutoStep(hObject)
    end
end


handles = guidata(hObject);

%- COMPUTE NEW STATE -
% -- compute new time --
if timeStep ~= 0 %&& handles.modelState.dT ~= handles.modelInfo.lim.dTstepLCP
    handles.modelState.dT   = round(handles.modelState.dT/timeStep)*timeStep + timeStep; %fix rounding errors
    handles.modelState.t    = round(handles.modelState.t/timeStep)*timeStep + timeStep;
end
handles.modelState.dTWait = max(0, handles.modelInfo.dTmin - handles.modelState.dT);

% -- compute new state --
[handles.modelState.rIC, handles.modelState.r2, handles.modelState.r, handles.modelState.rd] = NStep_evolve(handles.modelState.rIC, handles.modelState.r2,handles.modelState.rAnkle,timeStep);
% -- store derived state data in local axis--
handles.plotData.CoMTrajectory = [handles.plotData.CoMTrajectory handles.modelState.r];
rAnkleRot = DFP_rotmat(handles.modelInfo.lim.yaw) * handles.modelState.rAnkle;
rRot = DFP_rotmat(handles.modelInfo.lim.yaw) * handles.modelState.r;
rdRot = DFP_rotmat(handles.modelInfo.lim.yaw) * handles.modelState.rd;

handles.plotData.x =  [handles.plotData.x -rAnkleRot(1) + rRot(1)];
handles.plotData.y =  [handles.plotData.y -rAnkleRot(2) + rRot(2)];
handles.plotData.dx =  [handles.plotData.dx rdRot(1)];
handles.plotData.dy = [handles.plotData.dy rdRot(2)];

% Compute capture point at first possible step time
handles.plotData.rCPAtMinStep    = NStep_evolve(handles.modelState.rIC, handles.modelState.r2, handles.modelState.rAnkle, handles.modelState.dTWait);

% Compute Capture regions
handles.plotData.captureRegions = NStep_getCaptureRegions(handles.modelInfo,handles.modelState, handles.plotSettings);

% - FUTURE FEASIBLE STEP LOCATIONS -
% -- compute step points to get back onto limit cycle --
[stepLocationLCP, dTstepLCP, strategy]          = DFP_autostep_DFP(handles);
handles.modelInfo.lim.dTstepLCP                 = dTstepLCP;
handles.plotData.rLCP                           = stepLocationLCP;
handles.plotData.LCPstrategyNr                 = strategy;

%dtWaitTillStep = max(handles.modelInfo.dTmin, handles.modelState.dT);
handles.modelInfo.lim.dTstep;
stepLocationConstant                                 = DFP_autostep_Constant(handles.modelState, handles.modelInfo, handles.modelInfo.lim.dTstep, false);
handles.plotData.rConstant                           = stepLocationConstant;

N =4e2;
if length(handles.plotData.x) == N + 1;
    handles.plotData.x = handles.plotData.x(2: N+ 1);
    handles.plotData.y = handles.plotData.y(2: N+ 1);
    handles.plotData.dx = handles.plotData.dx(2: N+ 1);
    handles.plotData.dy = handles.plotData.dy(2: N+ 1);
end

guidata(hObject, handles);
end

%% FUNCTION: DRAW DATA
function drawData(hObject)

handles = guidata(hObject);

% Capture Regions
for k = 1 : length(handles.plotData.captureRegions)
    j = length(handles.plotData.captureRegions) - k + 1; % reverse iterate
    set(handles.plotHandles.captureRegionPatches(k),...
        'XData',handles.plotData.captureRegions{j}.boundary.x,...
        'YData',handles.plotData.captureRegions{j}.boundary.y,...,
        'FaceColor',handles.plotSettings.captureRegionColors(j, :),...
        'EdgeColor',handles.plotSettings.captureRegionColors(j, :));
    set(handles.plotHandles.captureRegionPatches(k), 'Visible', 'on')
end
for k = length(handles.plotData.captureRegions) + 1 : length(handles.plotHandles.captureRegionPatches)
    set(handles.plotHandles.captureRegionPatches(k), 'Visible', 'off')
end
%____________________________________________
% State specific plot settings
if handles.modelState.dTWait == 0 && (norm(handles.modelState.rAnkle - (handles.modelState.r + handles.modelState.rd)) < handles.modelInfo.lMax)
    CPMarkerColor = 'r';
else
    CPMarkerColor = 'none';
end


if handles.plotData.LCPstrategyNr == 1
    LCPColor = handles.plotSettings.colors.Green;
elseif handles.plotData.LCPstrategyNr == 2
    LCPColor = handles.plotSettings.colors.Orange;
elseif handles.plotData.LCPstrategyNr == 3
    LCPColor = handles.plotSettings.colors.Red;
elseif handles.plotData.LCPstrategyNr == 4
    LCPColor = handles.plotSettings.colors.Pink;
elseif handles.plotData.LCPstrategyNr == 5
    LCPColor = handles.plotSettings.colors.Brown;
elseif handles.plotData.LCPstrategyNr == 6
    LCPColor = handles.plotSettings.colors.Purple;
else
    LCPColor = 'none';
end

handles.plotData.CPLineEnd = handles.plotData.rCPAtMinStep;

% Set position data for all the plot elements
set(handles.plotHandles.CPLine,   'XData', [handles.modelState.rAnkle(1), handles.plotData.CPLineEnd(1)], 'YData', [handles.modelState.rAnkle(2), handles.plotData.CPLineEnd(2)],'Visible','on'); % Capture Point line
set(handles.plotHandles.legLink, 'XData', [handles.modelState.r(1); handles.modelState.rAnkle(1)], 'YData', [handles.modelState.r(2); handles.modelState.rAnkle(2)]); % Leg link
legPiston = handles.modelState.r - 0.5*norm(handles.modelState.r - handles.modelState.rAnkle) * (handles.modelState.r - handles.modelState.rAnkle) / norm(handles.modelState.r - handles.modelState.rAnkle);
set(handles.plotHandles.legLinkPiston, 'XData', [handles.modelState.r(1); legPiston(1)], 'YData', [handles.modelState.r(2); legPiston(2)]); % Leg link
set(handles.plotHandles.anklePositionsPlot, 'XData', handles.plotData.footPositions(1, :), 'YData', handles.plotData.footPositions(2, :)); % Foot position
set(handles.plotHandles.CoMTrajectoryPlot, 'XData', handles.plotData.CoMTrajectory(1, :), 'YData', handles.plotData.CoMTrajectory(2, :)); % CoM Trajectory
set(handles.plotHandles.ICMarker, 'Position', [handles.modelState.rIC(1)-handles.plotSettings.markerSize.ICMarkerR, handles.modelState.rIC(2)-handles.plotSettings.markerSize.ICMarkerR,2*handles.plotSettings.markerSize.ICMarkerR, 2*handles.plotSettings.markerSize.ICMarkerR], 'FaceColor',CPMarkerColor); % Instantaneous Capture Point
set(handles.plotHandles.ConstantMarker, 'Position', [handles.plotData.rConstant(1)-handles.plotSettings.markerSize.ConstantMarkerR, handles.plotData.rConstant(2)-handles.plotSettings.markerSize.ConstantMarkerR,2*handles.plotSettings.markerSize.ConstantMarkerR, 2*handles.plotSettings.markerSize.ConstantMarkerR],'FaceColor',handles.plotSettings.colors.Pink); % A Capture Point
set(handles.plotHandles.LCPMarker, 'Position', [handles.plotData.rLCP(1)-handles.plotSettings.markerSize.LCPMarkerR, handles.plotData.rLCP(2)-handles.plotSettings.markerSize.LCPMarkerR,2*handles.plotSettings.markerSize.LCPMarkerR, 2*handles.plotSettings.markerSize.LCPMarkerR],'FaceColor',LCPColor);
set(handles.plotHandles.AnkleMarker,'Position',[handles.modelState.rAnkle(1)-handles.plotSettings.markerSize.AnkleMarkerR, handles.modelState.rAnkle(2)-handles.plotSettings.markerSize.AnkleMarkerR,2*handles.plotSettings.markerSize.AnkleMarkerR, 2*handles.plotSettings.markerSize.AnkleMarkerR]);
set(handles.plotHandles.CoMMarker,'Position', [handles.modelState.r(1)-handles.plotSettings.markerSize.CoMMarkerR, handles.modelState.r(2)-handles.plotSettings.markerSize.CoMMarkerR,2*handles.plotSettings.markerSize.CoMMarkerR, 2*handles.plotSettings.markerSize.CoMMarkerR],'FaceColor', 'w');
R = DFP_rotmat(-handles.modelInfo.lim.yaw);
axisXRot = handles.modelState.rAnkle +  R*[handles.plotSettings.axisLength; 0];
axisYRot = handles.modelState.rAnkle +  R*[0; handles.plotSettings.axisLength];
axisXRotT = handles.modelState.rAnkle + R*[1.4* handles.plotSettings.axisLength; 0];
axisYRotT = handles.modelState.rAnkle + R*[0; 1.4*handles.plotSettings.axisLength];
set(handles.plotHandles.axisX, 'XData', [handles.modelState.rAnkle(1); axisXRot(1) ], 'YData', [handles.modelState.rAnkle(2); axisXRot(2)]); 
set(handles.plotHandles.axisY, 'XData', [handles.modelState.rAnkle(1); axisYRot(1) ], 'YData', [handles.modelState.rAnkle(2); axisYRot(2)]); 
set(handles.plotHandles.axisXText, 'Position', [axisXRotT(1), axisXRotT(2)]); 
set(handles.plotHandles.axisYText, 'Position', [axisYRotT(1), axisYRotT(2)]); 

[CoMFillX1, CoMFillY1]  = NStep_arcPoints(handles.modelState.r, handles.plotSettings.markerSize.CoMMarkerR, [0, 1/2*pi], handles.plotSettings.pointsPerRadian);
[CoMFillX2, CoMFillY2]  = NStep_arcPoints(handles.modelState.r, handles.plotSettings.markerSize.CoMMarkerR, [-pi, -1/2*pi], handles.plotSettings.pointsPerRadian);
set(handles.plotHandles.CoMFill,'XData', [CoMFillX1, fliplr(CoMFillX2)], 'YData', [CoMFillY1, fliplr(CoMFillY2)]);

% STATE SPACE FIGURES
set(handles.plotHandles.StateLine(1),   'XData', handles.plotData.x(1,:), 'YData', handles.plotData.dx(1,:));
set(handles.plotHandles.StateLine(2),   'XData', handles.plotData.y(1,:), 'YData', handles.plotData.dy(1,:));
set(handles.plotHandles.StateLine(3),   'XData', handles.plotData.x(1,:), 'YData', handles.plotData.y(1,:));
set(handles.plotHandles.StateLine(4),   'XData', handles.plotData.dx(1,:), 'YData', handles.plotData.dy(1,:));

MarkerR = handles.plotSettings.markerSize.StateMarkerR;
set(handles.plotHandles.StateMarker(1),'Position',[(handles.plotData.x(1,end)-MarkerR), (handles.plotData.dx(1,end) -MarkerR), 2*MarkerR, 2*MarkerR]);
set(handles.plotHandles.StateMarker(2),'Position',[(handles.plotData.y(end) - MarkerR), (handles.plotData.dy(end) -MarkerR), 2*MarkerR, 2*MarkerR]);
set(handles.plotHandles.StateMarker(3),'Position',[(handles.plotData.x(end) - MarkerR), (handles.plotData.y(end) -MarkerR), 2*MarkerR, 2*MarkerR]);
set(handles.plotHandles.StateMarker(4),'Position',[(handles.plotData.dx(end) - MarkerR), (handles.plotData.dy(end) -MarkerR), 2*MarkerR, 2*MarkerR]);

set(handles.plotHandles.limitCycle(1),   'XData', handles.plotData.xlim(1,:), 'YData', handles.plotData.dxlim(1,:));
set(handles.plotHandles.limitCycle(2),   'XData', handles.plotData.ylim(1,:), 'YData', handles.plotData.dylim(1,:));
set(handles.plotHandles.limitCycle(3),   'XData', handles.plotData.xlim(1,:), 'YData', handles.plotData.ylim(1,:));
set(handles.plotHandles.limitCycle(4),   'XData', handles.plotData.dxlim(1,:), 'YData', handles.plotData.dylim(1,:));

% ANIMATION INFO
set(handles.lx,'String',handles.modelInfo.lim.lx);
set(handles.ly,'String',handles.modelInfo.lim.ly);
set(handles.dTstep,'String',handles.modelInfo.lim.dTstep);
set(handles.lMax,'String',handles.modelInfo.lMax);
set(handles.dTmin,'String',handles.modelInfo.dTmin);
set(handles.yaw,'String',handles.modelInfo.lim.yaw);

set(handles.TimeText, 'String', sprintf('Time = %0.2f', handles.modelState.t)); % time
set(handles.dTTimeText, 'String', sprintf('t = %0.2f', handles.modelState.dT)); % time
set(handles.StanceNrText, 'String', sprintf('Stance # %d ', handles.modelState.stanceNr)); % time

%set(handles.dTLCPText, 'String', sprintf('DFC t_n = %0.2f ', handles.modelInfo.lim.dTstepLCP)); % time

% show step location
showStepLocation(hObject);

% panning
dynamicPanning(hObject);

% max step length circle
drawMaxStepCircles(hObject);
end

%% FUNCTION: draw max step length circles
function drawMaxStepCircles(hObject)
handles =guidata(hObject);

[handles.plotData.maxStepX, handles.plotData.maxStepY] = NStep_arcPoints(handles.modelState.rAnkle, handles.modelInfo.lMax, [-pi, pi], handles.plotSettings.pointsPerRadian);
handles.plotData.maxStepX(end + 1) = handles.plotData.maxStepX(1);
handles.plotData.maxStepY(end + 1) = handles.plotData.maxStepY(1);

if handles.plotData.panning
    % Fade step length circles
    numPanLoc = size(handles.plotData.panLocations,2);

    newMaxStepColors = colormap(handles.CartesianSpace, gray(numPanLoc));
    oldMaxStepColors = flipud(newMaxStepColors);

    newMaxStepColor = newMaxStepColors(handles.plotData.nPan, :);
    oldMaxStepColor = oldMaxStepColors(handles.plotData.nPan, :);

    set(handles.plotHandles.maxStepLengthCircle(1),'Color', newMaxStepColor);
    set(handles.plotHandles.maxStepLengthCircle(2),'XData', handles.plotData.maxStepX, 'YData', handles.plotData.maxStepY, 'Color', oldMaxStepColor, 'Visible', 'on');
else
    % Just show it
    set(handles.plotHandles.maxStepLengthCircle(1),'XData', handles.plotData.maxStepX, 'YData', handles.plotData.maxStepY);
    set(handles.plotHandles.maxStepLengthCircle(1),'Color','k');
    set(handles.plotHandles.maxStepLengthCircle(2),'Visible','off');
end
end
%%
function handles = setData(handles)
handles.modelInfo = DFP_setModelInfo();
handles.modelState = DFP_setModelState(handles);
handles.plotSettings = DFP_setPlotSettings(handles);
handles.plotData = DFP_setPlotData(handles);

end


%% NESTED FUNCTION: dynamically pan to a new ankle location
function dynamicPanning(hObject)
handles = guidata(hObject);
if handles.plotData.panning
    % first time around: compute panning locations
    if isempty(handles.plotData.panLocations)
        res = linspace(0, 1, 30);

        xCurrent = mean(get(handles.CartesianSpace, 'Xlim'));
        yCurrent = mean(get(handles.CartesianSpace, 'Ylim'));

        xSpan = [xCurrent, handles.modelState.rAnkle(1)] ;
        ySpan = [yCurrent, handles.modelState.rAnkle(2)] ;

        splineX = spline([0, 1],[0, xSpan, 0]);
        splineY = spline([0, 1],[0, ySpan, 0]);
        handles.plotData.panLocations  = [ppval(splineX, res); ppval(splineY, res)];
    end

    % Set axis
    panLocation = handles.plotData.panLocations(:, handles.plotData.nPan);
    guidata(hObject,handles)
    setAxis(panLocation,hObject);

    % Bookkeeping
    handles.plotData.nPan = handles.plotData.nPan + 1;
    if handles.plotData.nPan > size(handles.plotData.panLocations, 2)
        % done
        handles.plotData.panning = false;
        handles.plotData.panLocations = [];
        handles.plotData.nPan = [];
    end
    guidata(hObject,handles)
end

end

%% NESTED FUNCTION: handle the change of the foot location
%   change the modelstate based on a desired stepping action
function stepTo(newAnkleLocation, hObject)
handles = guidata(hObject);
epsilon = 1e-10;
withinReach             = (norm(newAnkleLocation - handles.modelState.rAnkle) - handles.modelInfo.lMax <= epsilon);
minStepTimeHasPassed    =handles.modelState.dTWait == 0;
% deside if desired location is feasible
if (withinReach && minStepTimeHasPassed)
    handles.modelState.rAnkle       = newAnkleLocation;
    handles.modelState.stanceNr     = handles.modelState.stanceNr + 1;
    handles.plotData.rAnkleNext     = [];
    handles.plotData.footPositions	= [handles.plotData.footPositions, handles.modelState.rAnkle];

    % Update modelState
    handles.modelState.dT           = 0;
    handles.modelState.dTWait       = handles.modelInfo.dTmin;

    % dfp_gui step location showing stuff
    handles.plotData.showStep   = true;
    handles.plotData.nShowStep  = 1;
    handles.plotData.panning    = true;
    handles.plotData.nPan       = 1;
    handles.plotData.realStep   = true;

elseif withinReach % store for future use
    handles.plotData.rAnkleNext = newAnkleLocation;
    handles.plotData.showStep   = true;
    handles.plotData.nShowStep  = 1;
    handles.plotData.realStep   = false;
else
    beep
end
guidata(hObject,handles);
end

%% NESTED FUNCTION: set figure axis
function setAxis(center,hObject)
% right Figure
handles = guidata(hObject);
axisSize = handles.plotSettings.axisSize;
xlim = [center(1) - 1/2 * axisSize, center(1) + 1/2 * axisSize];
ylim = [center(2) - 1/2 * axisSize, center(2) + 1/2 * axisSize];

set(handles.CartesianSpace, 'Xlim', xlim,'Ylim', ylim,'DataAspectRatio', [1,1,1]);
c = 2;

maxX = max(handles.plotData.xlim);
maxdX = max(handles.plotData.dxlim);
maxY = max(handles.plotData.ylim);
maxdY = max(handles.plotData.dylim);

limX = (c*[-maxX,maxX]);
limdX = (c*[-maxdX,maxdX]);
limY = (c*[-maxY,maxY]);
limdY = (c*[-maxdY,maxdY]);

set(handles.StateSpaceX,'Xlim', [-1,1],'Ylim', [-1,1], 'DataAspectRatio', [1,1,1]);
set(handles.StateSpaceY,'Xlim', .5*[-1,1],'Ylim', .5*[-1,1], 'DataAspectRatio', [1,1,1]);
set(handles.PositionPlot,'Xlim', .5*[-1,1],'Ylim',.5* [-1,1], 'DataAspectRatio', [1,1,1]);
set(handles.VelocityPlot,'Xlim', [0.3,0.8],'Ylim', .25*[-1,1], 'DataAspectRatio', [1,1,1]);

end

%% NESTED FUNCTION: highlight the new step location
function showStepLocation(hObject)
handles = guidata(hObject);
% show red dot
if ~isempty(handles.plotData.rAnkleNext)
    circleRadius = 0.015 * 0.5;

    x = handles.plotData.rAnkleNext(1) - circleRadius;
    y = handles.plotData.rAnkleNext(2) - circleRadius;
    w = 2 * circleRadius;
    h = w;

    set(handles.plotHandles.stepLocator(1),'Position', [x, y, w, h],...
        'Visible', 'on');
end

% flash step locators
if handles.plotData.showStep
    if handles.plotData.realStep
        stepLocation = handles.modelState.rAnkle;
    else
        stepLocation = handles.plotData.rAnkleNext;
    end

    % time setting
    dtFlash = 0.25;
    nFlash = ceil(dtFlash / handles.plotSettings.matlabTimerStep);

    if handles.plotData.nShowStep <= nFlash
        flashStep = ceil(6 * handles.plotData.nShowStep / nFlash);
        if flashStep < 4
            circleRadius = 0.015 * 0.5* flashStep^2;
            x = stepLocation(1) - circleRadius;
            y = stepLocation(2) - circleRadius;
            w = 2 * circleRadius;
            h = w;
            set(handles.plotHandles.stepLocator(flashStep),'Position', [x, y, w, h],...
                'Visible', 'on');
        else
            set(handles.plotHandles.stepLocator(flashStep - 3), 'Visible', 'off');
        end
    end

    if handles.plotData.nShowStep > nFlash
        % done
        handles.plotData.showStep = false;
        handles.plotData.nShowStep = [];
        handles.plotData.realStep = [];
    end

    handles.plotData.nShowStep = handles.plotData.nShowStep + 1;
end
guidata(hObject,handles);
end


function CheckDoAutoStep(hObject)
handles = guidata(hObject);
if handles.plotData.ConstantStepping == true && handles.modelInfo.lim.dTstep == handles.modelState.dT
    stepLocation = handles.plotData.rConstant;
    stepTo(stepLocation, hObject);
elseif handles.plotData.DFPControl == true &&...
        handles.modelInfo.lim.dTstepLCP + handles.plotSettings.stateTimeStep > handles.modelState.dT &&...
        handles.modelInfo.lim.dTstepLCP - handles.plotSettings.stateTimeStep < handles.modelState.dT
    % Go back/forward in time a bit to step at the right dTstepLCP step
    % time, (discrepancy between continuous time solutions and discrete timer)
    dTstepLCP = -(handles.modelState.dT - handles.modelInfo.lim.dTstepLCP);
    handles.modelState.t  = handles.modelState.t - dTstepLCP;
    handles.modelState.dT = handles.modelState.dT - dTstepLCP;
    [handles.modelState.rIC, handles.modelState.r2, handles.modelState.r, handles.modelState.rd] = NStep_evolve(handles.modelState.rIC, handles.modelState.r2, handles.modelState.rAnkle, dTstepLCP);
    stepLocation = handles.plotData.rLCP;
    guidata(hObject,handles)
    stepTo(stepLocation, hObject);
end


end



%

% --- Executes during object creation, after setting all properties.
function figure1_CreateFcn(hObject, eventdata, handles)
end

% --- Executes during object creation, after setting all properties.
function Constant_CreateFcn(hObject, eventdata, handles)
end

% --- Executes on mouse press over axes background.
function CartesianSpace_ButtonDownFcn(hObject, eventdata, handles)
end

% --- Executes during object creation, after setting all properties.
function startButton_CreateFcn(hObject, eventdata, handles)
end



function dTmin_Callback(hObject, eventdata, handles)
% Hints: get(hObject,'String') returns contents of dTmin as text
%        str2double(get(hObject,'String')) returns contents of dTmin as a double
handles = guidata(hObject);
dTmin = str2double(get(hObject,'String'));
handles.modelInfo.dTmin = dTmin;
guidata(hObject,handles)

end


function dTstep_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
dTstep = str2double(get(hObject,'String'));
handles.modelInfo.lim.dTstep = dTstep;


[xlim, ylim, dxlim, dylim] = DFP_calculateLimitCycle(handles.modelInfo);
handles.plotData.xlim                        = xlim;
handles.plotData.dxlim                       = dxlim;
handles.plotData.ylim                        = ylim;
handles.plotData.dylim                       = dylim;
guidata(hObject,handles);
end


function lMax_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
lMax = str2double(get(hObject,'String'));
handles.modelInfo.lMax = lMax;
guidata(hObject,handles);
end

function lx_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
lx = str2double(get(hObject,'String'));
handles.modelInfo.lim.lx = lx;
[xlim, ylim, dxlim, dylim] = DFP_calculateLimitCycle(handles.modelInfo);
handles.plotData.xlim                        = xlim;
handles.plotData.dxlim                       = dxlim;
handles.plotData.ylim                        = ylim;
handles.plotData.dylim                       = dylim;
guidata(hObject,handles);
end

function ly_Callback(hObject, eventdata, handles)
handles = guidata(hObject);
ly = str2double(get(hObject,'String'));
handles.modelInfo.lim.ly = ly;
[xlim, ylim, dxlim, dylim] = DFP_calculateLimitCycle(handles.modelInfo);
handles.plotData.xlim                        = xlim;
handles.plotData.dxlim                       = dxlim;
handles.plotData.ylim                        = ylim;
handles.plotData.dylim                       = dylim;
guidata(hObject,handles);

end


function yaw_Callback(hObject, eventdata, handles)

handles = guidata(hObject);
yaw = str2double(get(hObject,'String'));
handles.modelInfo.lim.yaw = yaw;
[xlim, ylim, dxlim, dylim] = DFP_calculateLimitCycle(handles.modelInfo);
handles.plotData.xlim                        = xlim;
handles.plotData.dxlim                       = dxlim;
handles.plotData.ylim                        = ylim;
handles.plotData.dylim                       = dylim;
guidata(hObject,handles);
end



function dTstep_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
end
function lMax_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
end

function lx_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

end
function ly_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
end
function dTmin_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
end

function yaw_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
end

function DFC_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
end


% --- Executes when selected object is changed in uipanel9.
function uipanel9_SelectionChangeFcn(hObject, eventdata, handles)
% hObject    handle to the selected object in uipanel9 
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
handles.plotData.ConstantStepping = false;
handles.plotData.DFPControl = false;
switch get(hObject,'Tag')   % Get Tag of selected object
    case 'DFC'
        handles.plotData.DFPControl = true;
    case 'Constant'
        handles.plotData.ConstantStepping = true;
    case 'None'
        % Code for when togglebutton1 is selected.
    otherwise
        disp('Radiobutton error')
end
guidata(hObject,handles);
end






