function [newStepLocation, dTstep] = DFP_autostep_Constant(modelState, modelInfo, dTstep, constrain_lMax)

%DFP_autostep_Constant
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $


if nargin == 3
    constrain_lMax = false;
end
if nargin == 2
    dTstep = modelInfo.lim.dTstep;
end

% dTstep is relative time till step, measured from last step

% modelState.r                   
% modelState.rd                  
% modelState.rAnkle              
% modelState.t                   
% modelState.dT                  
% modelState.stanceNr            
% modelState.rIC                 
% modelState.r2                  
% modelState.dTWait 

% modelInfo.dTmin         
% modelInfo.lMax          
% modelInfo.lim.dTstep    
% modelInfo.lim.lx        
% modelInfo.lim.ly        
% modelInfo.lim.yaw    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Instantaneous Capture Point of model at desired step time
dTWaitTillStep      = max(0, dTstep - modelState.dT);
rIC    = NStep_evolve(modelState.rIC, modelState.r2, modelState.rAnkle, dTWaitTillStep);

% Constant line offset in state space
bx = modelInfo.lim.lx/(exp(modelInfo.lim.dTstep) - 1);
by = modelInfo.lim.ly/(exp(modelInfo.lim.dTstep) + 1)*(-1)^(modelState.stanceNr);

alfa = modelInfo.lim.yaw;
b = [cosd(alfa) -sind(alfa); sind(alfa) cosd(alfa)] * [bx; by];
newStepLocation(1,1) = rIC(1) - b(1);
newStepLocation(2,1) = rIC(2) + b(2);

S = modelState.rAnkle-newStepLocation;
newStepLocation = modelState.rAnkle-S;

% Give empty if outside lMax circle
if constrain_lMax && norm(S) > modelInfo.lMax
    newStepLocation =[];
    dTstep = NaN;
end

end

