function [newStepLocation, dTstep, strategy] = DFP_autostep_LimitCycle(handles)

%DFP_autostep_LimitCycle
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $

% get model state and model info from handles
modelState = handles.modelState;
modelInfo = handles.modelInfo;

% rotate the state with the yaw angle
alpha = modelInfo.lim.yaw;
R = @(alpha) [cosd(alpha) -sind(alpha); sind(alpha) cosd(alpha)]; % rotation matrix
modelState.r =  R(alpha)* modelState.r;
modelState.rd = R(alpha)* modelState.rd;
modelState.rAnkle = R(alpha)* modelState.rAnkle;
modelState.rIC = R(alpha)* modelState.rIC;
modelState.r2 = R(alpha)* modelState.r2;

% initialize newStepLocation 
newStepLocation = [];

% 0-step: check if we are on:
if isempty(newStepLocation)
    strategy = 1; % green
    [newStepLocation, dTstep] = DFP_autostep_DFP_0step(modelState, modelInfo);
end

% 1-step: check if we can step to it in one step
if isempty(newStepLocation)
    strategy = 2; % orange
    [newStepLocation, dTstep] = DFP_autostep_DFP_1step(modelState, modelInfo);
end

% 2-step: check if we can step to it in two steps
if isempty(newStepLocation)
    strategy = 3; % red
    [newStepLocation, dTstep] = DFP_autostep_DFP_2step(modelState, modelInfo);
end

% (N>2)-step strategy
if isempty(newStepLocation)
    [newStepLocation, dTstep] = DFP_autostep_DFP_Nstep(modelState, modelInfo);
    strategy = 4; %pink
end

% rotate step location with yaw angle
newStepLocation = R(-alpha)* newStepLocation;