function [newStepLocation, dTstep] = DFP_autostep_DFP_0step(modelState, modelInfo)

%DFP_autostep_DFP_0step
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $

% Settings
epsilonX    = 1e-4;
epsilonTime = 0.01;

% Limit cycle state q_f^star
xlim   = modelInfo.lim.lx/2;
ylim   = modelInfo.lim.ly/2*(-1)^(modelState.stanceNr);
dxlim  = DFP_equations('dx1','x0',0,'x1',xlim,'t',modelInfo.lim.dTstep/2);
dylim  = DFP_equations('dx1','dx0',0,'x1',ylim,'t',modelInfo.lim.dTstep/2);

% Relative current state
x0 =  modelState.r(1)-modelState.rAnkle(1);
y0 =  modelState.r(2)-modelState.rAnkle(2);
dx0 = modelState.rd(1);
dy0 = modelState.rd(2);

% Time to lc point in x-dir
[dx1, t] = DFP_equations('dx1','t','dx0',dx0,'x0',x0,'x1',xlim);
x1 = xlim;
if isempty(dx1) || numel(dx1)==2
    dTstep = NaN;
    newStepLocation = []; 
    return
end

% State at t in y-dir
[y1,dy1] = DFP_equations('x1','dx1','dx0',dy0,'x0',y0,'t',t);

if  norm([x1,dx1]-[xlim,dxlim])< epsilonX &&... % check x-dir
    norm([y1,dy1]-[ylim,dylim])< epsilonX &&... % check y-dir
    modelState.dT+t >= modelInfo.dTmin-epsilonTime; % check time

    dTstep = modelState.dT + t; 
    newStepLocation(1,1) = modelState.rAnkle(1)+modelInfo.lim.lx;
    newStepLocation(2,1) = modelState.rAnkle(2)+modelInfo.lim.ly*sign(y0);
else
    dTstep = NaN;
    newStepLocation = []; 
end
