function [newStepLocation, dTstep] = DFP_autostep_DFP_2step(modelState, modelInfo)

%DFP_autostep_DFP_2step
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $


% Limit cycle state q_f^star
xlim   = modelInfo.lim.lx/2;
ylim   = modelInfo.lim.ly/2*(-1)^(modelState.stanceNr+2);
dxlim  = DFP_equations('dx1','x0',0,'x1',xlim,'t',modelInfo.lim.dTstep/2);
dylim  = DFP_equations('dx1','dx0',0,'x1',ylim,'t',modelInfo.lim.dTstep/2);

% Relative current state
x0 =  modelState.r(1)-modelState.rAnkle(1);
y0 =  modelState.r(2)-modelState.rAnkle(2);
dx0 = modelState.rd(1);
dy0 = modelState.rd(2);

% Select t0, t1 and t2 to be t_min
t0 = max(modelInfo.dTmin-modelState.dT,0);
t1 = modelInfo.dTmin;
t2 = modelInfo.dTmin;

% Determine step size for the first and second step (eqn (17) and (18)) 
Sx0 =-(dx0*cosh(t0 + t1) + x0*sinh(t0 + t1) - dxlim*cosh(t2) + xlim*sinh(t2))/sinh(t1);
Sy0 =-(dy0*cosh(t0 + t1) + y0*sinh(t0 + t1) - dylim*cosh(t2) + ylim*sinh(t2))/sinh(t1);
Sx1 =(xlim*sinh(t1 + t2) - dxlim*cosh(t1 + t2) + dx0*cosh(t0) + x0*sinh(t0))/sinh(t1);
Sy1 =(ylim*sinh(t1 + t2) - dylim*cosh(t1 + t2) + dy0*cosh(t0) + y0*sinh(t0))/sinh(t1);

if norm([Sx0,Sy0])<modelInfo.lMax && ... % check step size first step
   norm([Sx1,Sy1])<modelInfo.lMax        % check step size second step
    dTstep = modelState.dT + t0;
    newStepLocation(1,1) = modelState.rAnkle(1)-Sx0;
    newStepLocation(2,1) = modelState.rAnkle(2)-Sy0;
else
    dTstep = NaN;
    newStepLocation = [];
end


