function [newStepLocation, dTstep] = DFP_autostep_DFP_Nstep(modelState, modelInfo)

%DFP_autostep_DFP_Nstep
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $


% Relative current state
x0 =  modelState.r(1)-modelState.rAnkle(1);
y0 =  modelState.r(2)-modelState.rAnkle(2);
dx0 = modelState.rd(1);
dy0 = modelState.rd(2);

% State at moment of step
t = max(modelInfo.dTmin-modelState.dT,0);
[x0f,dx0f] = DFP_equations('x1','dx1','x0',x0,'dx0',dx0,'t',t);
[y0f,dy0f] = DFP_equations('x1','dx1','x0',y0,'dx0',dy0,'t',t);

%% Step at constant offset point
% Determine step size (see eqn (19))
Sx = x0f+dx0f + (-modelInfo.lim.lx/(exp(modelInfo.lim.dTstep)-1));
Sy = y0f+dy0f + (modelInfo.lim.ly/(exp(modelInfo.lim.dTstep)+1))*(-1)^modelState.stanceNr;

if norm([Sx,Sy])<modelInfo.lMax % check step size
    dTstep = modelState.dT + t;
    newStepLocation(1,1) = modelState.rAnkle(1)+Sx;
    newStepLocation(2,1) = modelState.rAnkle(2)+Sy;
    return
end

%% Step at instantaneous capture point
Sx = x0f+dx0f;
Sy = y0f+dy0f;
if norm([Sx,Sy])<modelInfo.lMax % check step size
    dTstep = modelState.dT + t;
    newStepLocation(1,1) = modelState.rAnkle(1)+Sx;
    newStepLocation(2,1) = modelState.rAnkle(2)+Sy;
    return
end

%% Step in the direction of instantaneous capture point with max step size
S = [Sx;Sy];
newStepLocation = modelState.rAnkle + modelInfo.lMax * S/norm(S);
dTstep = modelState.dT + t;
