function [xlim, ylim, dxlim, dylim] = DFP_calculateLimitCycle(modelInfo)

%DFP_calculateLimitCycle
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $


% Desired 2 step limit cycle
% X direction
x0 = -modelInfo.lim.lx/2;
t = modelInfo.lim.dTstep;
dx0 = DFP_equations('dx0','x0',x0,'x1',-x0,'t',t);
t_span = 0:0.01:t;
[xlim, dxlim] = gridfun(@(t) DFP_equations('x1','dx1','x0',x0,'dx0',dx0,'t',t),t_span);

% Y direction
y0 = -modelInfo.lim.ly/2;
t = modelInfo.lim.dTstep;
dy0 = DFP_equations('dx0','x0',y0,'x1',y0,'t',t);
t_span = 0:0.01:t;
[ylim, dylim] = gridfun(@(t) DFP_equations('x1','dx1','x0',y0,'dx0',dy0,'t',t),t_span);


xlim    = [xlim;    xlim;   xlim(1)];
dxlim   = [dxlim;   dxlim;  dxlim(1)];
ylim    = [ylim;    -ylim;  ylim(1)];
dylim   = [dylim;   -dylim; dylim(1)];

xlim = xlim.';
ylim = ylim.';
dxlim = dxlim.';
dylim = dylim.';

end