function modelState =  DFP_setModelState(handles)

%DFP_setModelState
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $


modelInfo = handles.modelInfo;
modelState.t                    = 0;              % absolute time
modelState.dT                   = 0;              % time since last step
modelState.stanceNr             = 0;              % number of stance phases
q_lim = [-1/2*modelInfo.lim.lx,...
    1/2*modelInfo.lim.ly *(-1)^modelState.stanceNr, ...
    1/2*modelInfo.lim.lx*coth(1/2*modelInfo.lim.dTstep),...
    -1/2*modelInfo.lim.ly*tanh(1/2*modelInfo.lim.dTstep)*(-1)^modelState.stanceNr];
a=0.0;
modelState.r                    = [q_lim(1); q_lim(2)];    % CoM location projected onto the floor
modelState.rd                   = [q_lim(3)-a; q_lim(4)-a];    % CoM velocity
modelState.rAnkle               = [0;0];          % ankle location.
modelState.rIC                  = modelState.r + modelState.rd;     % instantaneous capture point of current state, i.e. at dT since last step
modelState.r2                   = modelState.r - modelState.rd;     % 'State 2'
modelState.dTWait               = max(0, handles.modelInfo.dTmin - modelState.dT); % Time remaining until a step is allowed

end
 