function plotHandles = DFP_setPlotHandles(handles)

%DFP_setPlotHandles
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $


plotSettings = handles.plotSettings;
% Create handles to everything in the axis
hold(handles.CartesianSpace,'on');

% CARTESIAN SPACE
% Capture Regions
for i = 1 : (plotSettings.NMax+2)
    plotHandles.captureRegionPatches(i) = patch(0, 0,'k','EdgeColor','none','Parent',handles.CartesianSpace); %#ok<AGROW> %, plotSettings.captureRegionColors(j, :),'EdgeColor', 'none'); 
end

plotHandles.maxStepLengthCircle(1)  = plot(handles.CartesianSpace,0, 0, '-', 'Color',[0 0 0],'EraseMode', plotSettings.eraseMode,'Visible','on'); % Max Step Length circle
plotHandles.maxStepLengthCircle(2)  = plot(handles.CartesianSpace,0, 0, '-', 'Color',[0 0 0],'EraseMode', plotSettings.eraseMode,'Visible','on'); % Max Step Length circle
plotHandles.CPLine                  = plot(handles.CartesianSpace,0, 0, ':', 'Color',plotSettings.colors.Blue,'EraseMode', 'normal','Visible','on'); % CP line
plotHandles.CoMTrajectoryPlot       = plot(handles.CartesianSpace,0, 0, '-', 'Color',[0 0 0],'LineWidth',0.5,'EraseMode', plotSettings.eraseMode,'Visible','on'); % Center of Mass trajectory
plotHandles.legLink                 = plot(handles.CartesianSpace,0, 0, '-', 'Color',[0 0 0],'LineWidth',1.5,'EraseMode', plotSettings.eraseMode,'Visible','on'); % Leg link
plotHandles.legLinkPiston           = plot(handles.CartesianSpace,0, 0, '-', 'Color',[0 0 0],'LineWidth',3,'EraseMode', plotSettings.eraseMode,'Visible','on'); % Leg link
plotHandles.anklePositionsPlot      = plot(handles.CartesianSpace,0, 0, 'o', 'Color',[0 0 0],'MarkerSize', 5, 'EraseMode', plotSettings.eraseMode,'Visible','on'); % rPointFoot position
plotHandles.ICMarker                = rectangle('Parent',handles.CartesianSpace,'EdgeColor',plotSettings.colors.Red,'FaceColor','none', 'Curvature',[1 1],'LineWidth',1,'EraseMode', plotSettings.eraseMode,'Visible','on');
plotHandles.LCPMarker               = rectangle('Parent',handles.CartesianSpace,'EdgeColor','k','FaceColor','none', 'Curvature',[1 1],'LineWidth',1,'EraseMode', plotSettings.eraseMode,'Visible','on');
plotHandles.ConstantMarker          = rectangle('Parent',handles.CartesianSpace,'EdgeColor',plotSettings.colors.lightRed,'FaceColor','none', 'Curvature',[1 1],'LineWidth',1,'EraseMode', plotSettings.eraseMode,'Visible','on');
plotHandles.AnkleMarker             = rectangle('Parent',handles.CartesianSpace,'EdgeColor',[0 0 0],'FaceColor','k', 'Curvature',[1 1],'LineWidth',0.5,'EraseMode', plotSettings.eraseMode,'Visible','on');
plotHandles.CoMMarker               = rectangle('Parent',handles.CartesianSpace,'EdgeColor',[0 0 0],'FaceColor',[1 1 1], 'Curvature',[1 1],'LineWidth',2,'EraseMode', plotSettings.eraseMode,'Visible','on');
plotHandles.stepLocator(1)          = rectangle('Parent',handles.CartesianSpace,'EdgeColor','none','FaceColor',plotSettings.colors.Red, 'Curvature',[1 1],'LineWidth',1,'EraseMode', plotSettings.eraseMode,'Visible','off');
plotHandles.stepLocator(2)          = rectangle('Parent',handles.CartesianSpace,'EdgeColor',plotSettings.colors.Red,'FaceColor','none', 'Curvature',[1 1],'LineWidth',2,'EraseMode', plotSettings.eraseMode,'Visible','off');
plotHandles.stepLocator(3)          = rectangle('Parent',handles.CartesianSpace,'EdgeColor',plotSettings.colors.Red,'FaceColor','none', 'Curvature',[1 1],'LineWidth',2,'EraseMode', plotSettings.eraseMode,'Visible','off');
plotHandles.axisX                 = plot(handles.CartesianSpace,0, 0, '-', 'Color',[0 0 0],'LineWidth',0.1,'EraseMode', plotSettings.eraseMode,'Visible','on'); 
plotHandles.axisY                 = plot(handles.CartesianSpace,0, 0, '-', 'Color',[0 0 0],'LineWidth',0.1,'EraseMode', plotSettings.eraseMode,'Visible','on'); 
plotHandles.axisXText             = text('Parent', handles.CartesianSpace,'String','$x$', 'FontSize', 10, 'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', 'Interpreter','LateX');
plotHandles.axisYText             = text('Parent', handles.CartesianSpace,'String','$y$', 'FontSize', 10, 'HorizontalAlignment', 'center', 'VerticalAlignment', 'middle', 'Interpreter','LateX');
plotHandles.CoMFill                = patch(0,0,'k','Edgecolor','none','Parent',handles.CartesianSpace,'Visible','on');

%captureRegions = DFP_getCaptureRegions(handles.modelInfo, handles.modelState, handles.plotSettings);

% STATE SPACE PLOTS
a=10;
set(handles.StateSpaceX,'XGrid','on','YGrid','on','LineWidth',0.5,'DefaultTextInterpreter','LateX');
set(get(handles.StateSpaceX,'XLabel'),'String','$x$' ,'Rotation',0,'FontSize', a, 'Interpreter','LateX')
set(get(handles.StateSpaceX,'YLabel'),'String','$\dot{x}$' ,'Rotation',0,'FontSize', a, 'Interpreter','LateX')

set(handles.StateSpaceY,'XGrid','on','YGrid','on','LineWidth',0.5,'DefaultTextInterpreter','none');
set(get(handles.StateSpaceY,'XLabel'),'String','$y$','Rotation',0,'FontSize', a, 'Interpreter','LateX')
set(get(handles.StateSpaceY,'YLabel'),'String','$\dot{y}$','Rotation',0,'FontSize', a, 'Interpreter','LateX')

set(handles.PositionPlot,'XGrid','on','YGrid','on','LineWidth',0.5,'DefaultTextInterpreter','none');
set(get(handles.PositionPlot,'XLabel'),'String','$x$','Rotation',0,'FontSize', a, 'Interpreter','LateX')
set(get(handles.PositionPlot,'YLabel'),'String','$y$','Rotation',0,'FontSize', a, 'Interpreter','LateX')

set(handles.VelocityPlot,'XGrid','on','YGrid','on','LineWidth',0.5,'DefaultTextInterpreter','none');
set(get(handles.VelocityPlot,'XLabel'),'String','$\dot{x}$','Rotation',0,'FontSize', a, 'Interpreter','LateX')
set(get(handles.VelocityPlot,'YLabel'),'String','$\dot{y}$','Rotation',0,'FontSize', a, 'Interpreter','LateX')

% ,'Rotation',90


% 45 degreee lines
c =10;
corner1 = c*[1, -1]; corner2 = c*[-1, 1]; corner3 = c*[1, -1];
hold(handles.StateSpaceX,'on')
hold(handles.StateSpaceY,'on')
plot(handles.StateSpaceX, corner1, corner2,corner1, corner3,'Color',handles.plotSettings.colors.Brown);
plot(handles.StateSpaceY, corner1, corner2,corner1, corner3,'Color',handles.plotSettings.colors.Brown);



% Vector lines
syms x xd
s  = [x, xd]; sd = [xd, x];
c = 1.5;
xlimLeftY = (c*[-handles.modelInfo.lMax,handles.modelInfo.lMax]);
ylimLeftY = (c*[-handles.modelInfo.lMax,handles.modelInfo.lMax]);
xlimLeftX = (c*[-handles.modelInfo.lMax,handles.modelInfo.lMax]);
ylimLeftX = (c*[-handles.modelInfo.lMax,handles.modelInfo.lMax]);
vectline(handles.StateSpaceX,sd,s,[xlimLeftX,ylimLeftX],handles.plotSettings.colors.Brown);
vectline(handles.StateSpaceY,sd,s,[xlimLeftY,ylimLeftY],handles.plotSettings.colors.Brown);

% Limit cycle lines
plotHandles.limitCycle(1)  = plot(handles.StateSpaceX,0,0,'Color',handles.plotSettings.colors.Brown,'LineWidth',1.5,'Visible','on');
plotHandles.limitCycle(2)  = plot(handles.StateSpaceY,0,0,'Color',handles.plotSettings.colors.Brown,'LineWidth',1.5,'Visible','on');

% Current state lines
plotHandles.StateLine(1)           = plot(handles.StateSpaceX,0, 0, '-', 'Color','k','EraseMode', 'normal','LineWidth',2,'Visible','on');
plotHandles.StateLine(2)           = plot(handles.StateSpaceY,0, 0, '-', 'Color','k','EraseMode', 'normal','LineWidth',2,'Visible','on');
plotHandles.StateMarker(1)         = rectangle('Parent',handles.StateSpaceX,'EdgeColor','k','FaceColor','none', 'Curvature',[1 1],'LineWidth',1,'EraseMode', plotSettings.eraseMode,'LineWidth',2,'Visible','on');
plotHandles.StateMarker(2)         = rectangle('Parent',handles.StateSpaceY,'EdgeColor','k','FaceColor','none', 'Curvature',[1 1],'LineWidth',1,'EraseMode', plotSettings.eraseMode,'LineWidth',2,'Visible','on');

% POSITION / VELOCITY PLOTS
hold(handles.PositionPlot,'on')
hold(handles.VelocityPlot,'on')
% Limit cycle lines
plotHandles.limitCycle(3)  = plot(handles.PositionPlot,0,0,'Color',handles.plotSettings.colors.Brown,'LineWidth',1.5,'Visible','on');
plotHandles.limitCycle(4)  = plot(handles.VelocityPlot,0,0,'Color',handles.plotSettings.colors.Brown,'LineWidth',1.5,'Visible','on');

% Current state lines
plotHandles.StateLine(3)           = plot(handles.PositionPlot,0, 0, '-', 'Color','k','EraseMode', 'normal','LineWidth',2,'Visible','on');
plotHandles.StateLine(4)           = plot(handles.VelocityPlot,0, 0, '-', 'Color','k','EraseMode', 'normal','LineWidth',2,'Visible','on');
plotHandles.StateMarker(3)         = rectangle('Parent',handles.PositionPlot,'EdgeColor','k','FaceColor','none', 'Curvature',[1 1],'LineWidth',1,'EraseMode', plotSettings.eraseMode,'LineWidth',2,'Visible','on');
plotHandles.StateMarker(4)         = rectangle('Parent',handles.VelocityPlot,'EdgeColor','k','FaceColor','none', 'Curvature',[1 1],'LineWidth',1,'EraseMode', plotSettings.eraseMode,'LineWidth',2,'Visible','on');



end