function plotSettings = DFP_setPlotSettings(handles)

%DFP_setPlotSettings
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $


plotSettings.NMax                   = 4;        % Maximum N for the N-Step Capture limit. Note that an N+1-Step Capture Region can be plotted using the N-Step Capture limit.
plotSettings.pointsPerRadian        = 10;       % Number of points per radian to plot an arc
plotSettings.stateTimeStep          = 0.01;     % Time between frames
plotSettings.matlabTimerStep        = 0.04;      % Dimensionless simulated time between frames
plotSettings.marginFraction         = 1;        % Amount of white space around the max step length circle, fraction of step length
plotSettings.eraseMode              = 'normal';
plotSettings.axisSize               = handles.modelInfo.lMax * (2.5 + plotSettings.marginFraction);


% Marker size radius
plotSettings.markerSize.AnkleMarkerR= 0.015;
plotSettings.markerSize.CoMMarkerR  = 0.05;
plotSettings.markerSize.ICMarkerR   = 0.03;
plotSettings.markerSize.StateMarkerR = 0.05;
plotSettings.markerSize.ConstantMarkerR   = 0.015;
plotSettings.markerSize.LCPMarkerR   = 0.04;
plotSettings.axisLength = 0.18;

% Colors (also exist in CMYK color space for printing of the figure)
plotSettings.colors.lightRed        =[0.96 0.3 0.3];
plotSettings.colors.Red             =[0.93 0.11 0.14];
plotSettings.colors.Blue            =[0 0.07 1];
plotSettings.colors.Brown           =[0.78 0.6 .42];
plotSettings.colors.Green           =[0.0 0.6 .0];
plotSettings.colors.Orange          =[1 0.69 .39];
plotSettings.colors.Pink          =[1 0.6 .78];
plotSettings.colors.Purple          =[0.48 0.06 .89];

plotSettings.captureRegionColors = brighten(colormap(handles.CartesianSpace, summer(plotSettings.NMax + 2)), 0.4);




end