function oneStepCR = NStep_oneStepCaptureRegions(modelInfo, modelState, plotSettings)
%NSTEP_oneStepCaptureRegions
%   Returns the 1-step cature region for the different models
%   [ONESTEPCR] = NStep_oneStepCaptureRegions(MODELINFO, MODELSTATE,
%   PLOTSETTINGS, ENABLEREACTIONMASS, ENABLEBOS) returns the 1-step capture
%   region defined by the model variables MODELINFO, current model state 
%   MODELSTATE. PLOTSETTINGS describes the plotresolution and number of 
%   regions requested. Booleans ENABLEREACTIONMASS, 
%   ENABLEBOS set which model type should be selected for the 
%   calculations.ONESTEPCR [x1 x2 ..; y1 y2 ..] contains the point locations 
%   of border the 1-stepcapture region. NOt that this region should still 
%   be clipped to the maximum step length circlea and surrounded by an  
%   offset path at a distance determined by the maximum footlength.
%
%   This file is supplied as an addition to the draft paper:
%   "Analysis and Control of Legged Locomotion with Capture Points" 
%   - Part 2: Application to Three Simple Models -
%   submitted to IEEE TRO
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Twan Koolen,   f.a.koolen@student.tudelft.nl
%
%   Copyright 2010, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: February 2010 $


%% CASE 1: Model LIPM PointFoot


rCPdTStep       = NStep_ricEvolve(modelState.rIC, modelState.rAnkle, modelState.dTWait);
boundaryCase1   = case1_LIPMPointFoot(rCPdTStep,modelState,modelInfo);
oneStepCR       = store(boundaryCase1);


%% Store data
function oneStepCR = store(boundary)
oneStepCR.boundary.x    = boundary(1,:);
oneStepCR.boundary.y    = boundary(2,:);
end

%% End main function
end


% point foot model
function boundaryCase1 = case1_LIPMPointFoot(rCPdTStep,modelState,modelInfo)

ZeroStep = norm(rCPdTStep - modelState.rAnkle) < 1e-10;
if ZeroStep
    boundaryCase1 = modelState.rAnkle;
else
    boundaryCase1 = oneStepRegionLine(rCPdTStep,modelState,modelInfo);
end
    
end


%% oneStepRegionLine
% one step capture region line for a point foot model 
function boundary = oneStepRegionLine(rCPdTStep,modelState,modelInfo)
rCPdTStepDist   = norm(rCPdTStep- modelState.rAnkle);
boundary        = [rCPdTStep, modelState.rAnkle + vecUnit( modelState.rAnkle, rCPdTStep)*(rCPdTStepDist + modelInfo.lMax)];
end


%% vecUnit
% Create vector of unity length
function ret = vecUnit(Point1,Point2)
ret = (Point2-Point1)/norm(Point2-Point1);
end



