function [newStepLocation, dTstep] = DFP_autostep_DFP_1step(modelState, modelInfo)

%DFP_autostep_DFP_1step
%   This file is supplied as an addition to the draft paper:
%   "Foot Placement control: Step Location and Step Time as a
%   Function of the Desired Walking Gait"
%
%   For further information, contact:
%   Tomas de Boer, tomas.deboer@tudelft.nl, or    
%   Danil Karssen,   j.g.d.karssen@tudelft.nl
%
%   Copyright 2011, Delft BioRobotics Laboratory
%   Delft University of Technology
%   $Revision: 1.0 $  $Date: August 2011 $


% Settings
epsilonTime =  0.01;

% Limit cycle state q_f^star
xlim   = modelInfo.lim.lx/2;
ylim   = modelInfo.lim.ly/2*(-1)^(modelState.stanceNr+1);
dxlim  = DFP_equations('dx1','x0',0,'x1',xlim,'t',modelInfo.lim.dTstep/2);
dylim  = DFP_equations('dx1','dx0',0,'x1',ylim,'t',modelInfo.lim.dTstep/2);

% Relative current state
x0 =  modelState.r(1)-modelState.rAnkle(1);
y0 =  modelState.r(2)-modelState.rAnkle(2);
dx0 = modelState.rd(1);
dy0 = modelState.rd(2);

% Get t0 and t1 by solving eqn (14)  (see DFP_syms_solve_eqn14.m)
t0(1) = -log(2*((4*y0*dx0*dy0*x0-dylim^2*dx0^2-2*xlim*dy0*ylim*dx0+2*dxlim*dy0*dylim*dx0+dylim^2*x0^2+xlim^2*dy0^2-ylim^2*x0^2+ylim^2*dx0^2-2*dy0^2*x0^2-2*y0^2*dx0^2-xlim^2*y0^2+dxlim^2*y0^2-dxlim^2*dy0^2+2*xlim*y0*ylim*x0-2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0))^(1/2)*(x0*dy0-dx0*y0)/(ylim*x0-ylim*dx0-dylim*dx0-dxlim*y0+dylim*x0-xlim*y0+xlim*dy0+dxlim*dy0+(dxlim*dy0+ylim*dx0+dylim*x0-dylim*dx0-ylim*x0+xlim*y0-xlim*dy0-dxlim*y0)*(4*y0*dx0*dy0*x0-dylim^2*dx0^2-2*xlim*dy0*ylim*dx0+2*dxlim*dy0*dylim*dx0+dylim^2*x0^2+xlim^2*dy0^2-ylim^2*x0^2+ylim^2*dx0^2-2*dy0^2*x0^2-2*y0^2*dx0^2-xlim^2*y0^2+dxlim^2*y0^2-dxlim^2*dy0^2+2*xlim*y0*ylim*x0-2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0)));
t0(2) = -log(-2*((4*y0*dx0*dy0*x0-dylim^2*dx0^2-2*xlim*dy0*ylim*dx0+2*dxlim*dy0*dylim*dx0+dylim^2*x0^2+xlim^2*dy0^2-ylim^2*x0^2+ylim^2*dx0^2-2*dy0^2*x0^2-2*y0^2*dx0^2-xlim^2*y0^2+dxlim^2*y0^2-dxlim^2*dy0^2+2*xlim*y0*ylim*x0-2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0))^(1/2)*(x0*dy0-dx0*y0)/(ylim*x0-ylim*dx0-dylim*dx0-dxlim*y0+dylim*x0-xlim*y0+xlim*dy0+dxlim*dy0+(dxlim*dy0+ylim*dx0+dylim*x0-dylim*dx0-ylim*x0+xlim*y0-xlim*dy0-dxlim*y0)*(4*y0*dx0*dy0*x0-dylim^2*dx0^2-2*xlim*dy0*ylim*dx0+2*dxlim*dy0*dylim*dx0+dylim^2*x0^2+xlim^2*dy0^2-ylim^2*x0^2+ylim^2*dx0^2-2*dy0^2*x0^2-2*y0^2*dx0^2-xlim^2*y0^2+dxlim^2*y0^2-dxlim^2*dy0^2+2*xlim*y0*ylim*x0-2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0)));
t0(3) = -log(2*(-(-4*y0*dx0*dy0*x0+dylim^2*dx0^2+2*xlim*dy0*ylim*dx0-2*dxlim*dy0*dylim*dx0-dylim^2*x0^2-xlim^2*dy0^2+ylim^2*x0^2-ylim^2*dx0^2+2*dy0^2*x0^2+2*y0^2*dx0^2+xlim^2*y0^2-dxlim^2*y0^2+dxlim^2*dy0^2-2*xlim*y0*ylim*x0+2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0))^(1/2)*(x0*dy0-dx0*y0)/(ylim*x0-ylim*dx0-dylim*dx0-dxlim*y0+dylim*x0-xlim*y0+xlim*dy0+dxlim*dy0-(dxlim*dy0+ylim*dx0+dylim*x0-dylim*dx0-ylim*x0+xlim*y0-xlim*dy0-dxlim*y0)*(-4*y0*dx0*dy0*x0+dylim^2*dx0^2+2*xlim*dy0*ylim*dx0-2*dxlim*dy0*dylim*dx0-dylim^2*x0^2-xlim^2*dy0^2+ylim^2*x0^2-ylim^2*dx0^2+2*dy0^2*x0^2+2*y0^2*dx0^2+xlim^2*y0^2-dxlim^2*y0^2+dxlim^2*dy0^2-2*xlim*y0*ylim*x0+2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0)));
t0(4) = -log(-2*(-(-4*y0*dx0*dy0*x0+dylim^2*dx0^2+2*xlim*dy0*ylim*dx0-2*dxlim*dy0*dylim*dx0-dylim^2*x0^2-xlim^2*dy0^2+ylim^2*x0^2-ylim^2*dx0^2+2*dy0^2*x0^2+2*y0^2*dx0^2+xlim^2*y0^2-dxlim^2*y0^2+dxlim^2*dy0^2-2*xlim*y0*ylim*x0+2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0))^(1/2)*(x0*dy0-dx0*y0)/(ylim*x0-ylim*dx0-dylim*dx0-dxlim*y0+dylim*x0-xlim*y0+xlim*dy0+dxlim*dy0-(dxlim*dy0+ylim*dx0+dylim*x0-dylim*dx0-ylim*x0+xlim*y0-xlim*dy0-dxlim*y0)*(-4*y0*dx0*dy0*x0+dylim^2*dx0^2+2*xlim*dy0*ylim*dx0-2*dxlim*dy0*dylim*dx0-dylim^2*x0^2-xlim^2*dy0^2+ylim^2*x0^2-ylim^2*dx0^2+2*dy0^2*x0^2+2*y0^2*dx0^2+xlim^2*y0^2-dxlim^2*y0^2+dxlim^2*dy0^2-2*xlim*y0*ylim*x0+2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0)));
t1(1) = 1/2*log((4*y0*dx0*dy0*x0-dylim^2*dx0^2-2*xlim*dy0*ylim*dx0+2*dxlim*dy0*dylim*dx0+dylim^2*x0^2+xlim^2*dy0^2-ylim^2*x0^2+ylim^2*dx0^2-2*dy0^2*x0^2-2*y0^2*dx0^2-xlim^2*y0^2+dxlim^2*y0^2-dxlim^2*dy0^2+2*xlim*y0*ylim*x0-2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0));
t1(2) = log(-((4*y0*dx0*dy0*x0-dylim^2*dx0^2-2*xlim*dy0*ylim*dx0+2*dxlim*dy0*dylim*dx0+dylim^2*x0^2+xlim^2*dy0^2-ylim^2*x0^2+ylim^2*dx0^2-2*dy0^2*x0^2-2*y0^2*dx0^2-xlim^2*y0^2+dxlim^2*y0^2-dxlim^2*dy0^2+2*xlim*y0*ylim*x0-2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0))^(1/2));
t1(3) = 1/2*log(-(-4*y0*dx0*dy0*x0+dylim^2*dx0^2+2*xlim*dy0*ylim*dx0-2*dxlim*dy0*dylim*dx0-dylim^2*x0^2-xlim^2*dy0^2+ylim^2*x0^2-ylim^2*dx0^2+2*dy0^2*x0^2+2*y0^2*dx0^2+xlim^2*y0^2-dxlim^2*y0^2+dxlim^2*dy0^2-2*xlim*y0*ylim*x0+2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0));
t1(4) = log(-(-(-4*y0*dx0*dy0*x0+dylim^2*dx0^2+2*xlim*dy0*ylim*dx0-2*dxlim*dy0*dylim*dx0-dylim^2*x0^2-xlim^2*dy0^2+ylim^2*x0^2-ylim^2*dx0^2+2*dy0^2*x0^2+2*y0^2*dx0^2+xlim^2*y0^2-dxlim^2*y0^2+dxlim^2*dy0^2-2*xlim*y0*ylim*x0+2*dxlim*y0*dylim*x0+2*(4*xlim*dy0*ylim*dx0*dxlim*y0*dylim*x0+dylim^2*x0^2*xlim^2*dy0^2-dylim^2*x0^2*y0^2*dx0^2-2*dxlim*dy0^3*dylim*dx0*x0^2-2*dxlim*dy0*dylim*dx0^3*y0^2-xlim^2*dy0^2*y0^2*dx0^2-2*dxlim^2*dy0*ylim^2*dx0*y0*x0+ylim^2*x0^2*dxlim^2*dy0^2+ylim^2*x0^2*y0^2*dx0^2+ylim^2*dx0^2*dxlim^2*y0^2-ylim^2*dx0^2*dy0^2*x0^2+dy0^2*x0^2*xlim^2*y0^2-dy0^2*x0^2*dxlim^2*y0^2-2*dy0^2*x0^3*xlim*y0*ylim+2*dy0^2*x0^3*dxlim*y0*dylim-2*xlim*dy0^2*dxlim*ylim*x0^2*dylim+y0^2*dx0^2*dxlim^2*dy0^2-2*y0^3*dx0^2*xlim*ylim*x0+2*y0^3*dx0^2*dxlim*dylim*x0-2*xlim^2*dy0*dylim^2*dx0*y0*x0+ylim^2*x0^4*dy0^2-xlim^2*dy0^4*x0^2-dylim^2*x0^4*dy0^2+dylim^2*dx0^4*y0^2-y0^4*dx0^2*dxlim^2+y0^4*dx0^2*xlim^2+dy0^4*x0^2*dxlim^2-ylim^2*dx0^4*y0^2+y0^4*dx0^4+dy0^4*x0^4-2*ylim*dx0^2*dylim*xlim*y0^2*dxlim-2*y0*dx0^3*dy0*x0*dylim^2-4*y0*dx0^2*dy0^2*x0*xlim*ylim+4*y0*dx0^2*dy0^2*x0*dxlim*dylim-4*y0*dx0*dy0^3*x0^3+6*y0^2*dx0^2*dy0^2*x0^2-4*y0^3*dx0^3*dy0*x0+2*y0*dx0*dy0*x0^3*dylim^2+2*y0*dx0*dy0^3*x0*xlim^2-2*y0*dx0*dy0*x0^3*ylim^2-4*y0^2*dx0*dy0*x0^2*dxlim*dylim-2*y0*dx0*dy0^3*x0*dxlim^2+dylim^2*dx0^2*dy0^2*x0^2+2*y0*dx0^3*dy0*x0*ylim^2-2*y0^3*dx0*dy0*x0*xlim^2+2*y0^3*dx0*dy0*x0*dxlim^2+4*y0^2*dx0*dy0*x0^2*xlim*ylim+dylim^2*dx0^2*xlim^2*y0^2+2*xlim*dy0^3*ylim*dx0*x0^2+2*xlim*dy0*ylim*dx0^3*y0^2)^(1/2))/(ylim^2*dx0^2+dxlim^2*dy0^2+2*xlim*dy0*dylim*dx0-ylim^2*x0^2-dylim^2*x0^2+2*dxlim*dy0*ylim*dx0-2*ylim*dx0^2*dylim+dylim^2*dx0^2-2*xlim*dy0*ylim*dx0-xlim^2*y0^2+xlim^2*dy0^2-dxlim^2*y0^2+2*ylim*x0^2*dylim+2*xlim*y0^2*dxlim-2*xlim*dy0^2*dxlim-2*dxlim*dy0*dylim*dx0+2*xlim*y0*ylim*x0-2*xlim*y0*dylim*x0-2*dxlim*y0*ylim*x0+2*dxlim*y0*dylim*x0))^(1/2));

% Check t0 and t1
% Throw out imaginairy parts
sel = imag(t0)==0 & imag(t1)==0;
% Throw out Inf
sel = sel & isfinite(t0) & isfinite(t1);
% Throw out (t0+modelState.dT) < modelInfo.dTmin
sel = sel & (t0+modelState.dT) >= (modelInfo.dTmin - epsilonTime);
% Throw out t1 < modelInfo.dTmin
sel = sel & t1 >= (modelInfo.dTmin - epsilonTime);
t0 = t0(sel);
t1 = t1(sel);

if isempty(t0) % no valid solution
    dTstep = NaN;
    newStepLocation = [];
    return
end

% Determine step size for all possible options
for n=1:length(t0)
    x0f = DFP_equations('x1','x0',x0,'dx0',dx0,'t',t0(n));
    y0f = DFP_equations('x1','x0',y0,'dx0',dy0,'t',t0(n));
    x1i = DFP_equations('x0','x1',xlim,'dx1',dxlim,'t',t1(n));
    y1i = DFP_equations('x0','x1',ylim,'dx1',dylim,'t',t1(n));
    Sx(n) = x0f-x1i;
    Sy(n) = y0f-y1i;
    L(n) = sqrt(Sx(n).^2 + Sy(n).^2);
end

if any(L<=modelInfo.lMax) % check step size
    [not_used,index] = min(L); % select smallest step
    dTstep = t0(index)+modelState.dT;
    newStepLocation(1,1) = modelState.rAnkle(1)+Sx(index);
    newStepLocation(2,1) = modelState.rAnkle(2)+Sy(index);
else
    dTstep = NaN;
    newStepLocation = [];
end